==> conduit-4.1.8.tar.gz: README.md <==
<img src="https://raw.githubusercontent.com/conduit-dart/conduit/master/assets/conduit-name.svg" width="500" height="150">

[![Linux](https://github.com/conduit-dart/conduit/actions/workflows/linux.yml/badge.svg)](https://github.com/conduit-dart/conduit/actions/workflows/linux.yml) [![Windows](https://github.com/conduit-dart/conduit/actions/workflows/windows.yml/badge.svg)](https://github.com/conduit-dart/conduit/actions/workflows/windows.yml) [![Macos](https://github.com/conduit-dart/conduit/actions/workflows/macos.yml/badge.svg)](https://github.com/conduit-dart/conduit/actions/workflows/macos.yml) [<img src="https://discord.com/assets/3437c10597c1526c3dbd98c737c2bcae.svg" width="28" height="20">](https://discord.gg/MHz5cqktHW)

Conduit is a fork of Stablekernel's Aqueduct, a modern Dart HTTP server framework.

## Getting Started

1. [Install Dart](https://www.dartlang.org/install).
2. Activate Conduit.
```
dart pub global activate conduit
```
3. Create a new project.
```
conduit create my_project
```
4. Serve the project.
```
cd my_project
conduit serve
```

## Tutorials, Documentation and Examples

We are currently in the process of collating helpful resources for your edification. Our main docs live [here](https://docs.theconduit.dev/).

Conduit is a close fork to Aqueduct, so Aqueduct examples can be tweaked to work with Conduit [here](https://github.com/stablekernel/aqueduct_examples). The major concern is updating the code to use null-safety.

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://j4qfrost.github.io"><img src="https://avatars.githubusercontent.com/u/4009919?v=4?s=100" width="100px;" alt="j4qfrost"/><br /><sub><b>j4qfrost</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/commits?author=j4qfrost" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/neterror"><img src="https://avatars.githubusercontent.com/u/6708967?v=4?s=100" width="100px;" alt="neterror"/><br /><sub><b>neterror</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/commits?author=neterror" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/luis901101"><img src="https://avatars.githubusercontent.com/u/28322469?v=4?s=100" width="100px;" alt="Luis"/><br /><sub><b>Luis</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/commits?author=luis901101" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/crifurch"><img src="https://avatars.githubusercontent.com/u/11064662?v=4?s=100" width="100px;" alt="Artem Semirenko"/><br /><sub><b>Artem Semirenko</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/issues?q=author%3Acrifurch" title="Bug reports">🐛</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

==> conduit-5.0.3.tar.gz: README.md <==
<img src="https://raw.githubusercontent.com/conduit-dart/conduit/master/assets/conduit-name.svg" width="500" height="150">

[![Linux](https://github.com/conduit-dart/conduit/actions/workflows/linux.yml/badge.svg)](https://github.com/conduit-dart/conduit/actions/workflows/linux.yml) [![Windows](https://github.com/conduit-dart/conduit/actions/workflows/windows.yml/badge.svg)](https://github.com/conduit-dart/conduit/actions/workflows/windows.yml) [![Macos](https://github.com/conduit-dart/conduit/actions/workflows/macos.yml/badge.svg)](https://github.com/conduit-dart/conduit/actions/workflows/macos.yml) [<img src="https://discord.com/assets/3437c10597c1526c3dbd98c737c2bcae.svg" width="28" height="20">](https://discord.gg/MHz5cqktHW)
[![melos](https://img.shields.io/badge/maintained%20with-melos-f700ff.svg?style=flat-square)](https://github.com/invertase/melos)

Conduit is a fork of Stablekernel's Aqueduct, a modern Dart HTTP server framework.

## Getting Started

1. [Install Dart](https://www.dartlang.org/install).
2. Activate Conduit.
```
dart pub global activate conduit
```
3. Create a new project.
```
conduit create my_project
```
4. Serve the project.
```
cd my_project
conduit serve
```

## Tutorials, Documentation and Examples

We are currently in the process of collating helpful resources for your edification. Our main docs live [here](https://docs.theconduit.dev/).

Conduit is a close fork to Aqueduct, so Aqueduct examples can be tweaked to work with Conduit [here](https://github.com/stablekernel/aqueduct_examples). The major concern is updating the code to use null-safety.

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://j4qfrost.github.io"><img src="https://avatars.githubusercontent.com/u/4009919?v=4?s=100" width="100px;" alt="j4qfrost"/><br /><sub><b>j4qfrost</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/commits?author=j4qfrost" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/neterror"><img src="https://avatars.githubusercontent.com/u/6708967?v=4?s=100" width="100px;" alt="neterror"/><br /><sub><b>neterror</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/commits?author=neterror" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/luis901101"><img src="https://avatars.githubusercontent.com/u/28322469?v=4?s=100" width="100px;" alt="Luis"/><br /><sub><b>Luis</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/commits?author=luis901101" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/crifurch"><img src="https://avatars.githubusercontent.com/u/11064662?v=4?s=100" width="100px;" alt="Artem Semirenko"/><br /><sub><b>Artem Semirenko</b></sub></a><br /><a href="https://github.com/conduit-dart/conduit/issues?q=author%3Acrifurch" title="Bug reports">🐛</a> <a href="https://github.com/conduit-dart/conduit/commits?author=crifurch" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
